@@ -4,10 +4,10 @@ import os
 pwd = os.getcwd()
 os.system('export PYTHONPATH="${PYTHONPATH}:'+pwd+'"')
 
-import wifi
-import bt
-import util
-import archive
+import lib.wifi as wifi
+import lib.bt as bt
+import lib.util as util
+import lib.archive as archive
 
 
 main_app = typer.Typer()
